# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Championship'
        db.create_table(u'allejo_championship', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=200)),
            ('main_image', self.gf('django.db.models.fields.files.ImageField')(max_length=100, null=True, blank=True)),
            ('max_players', self.gf('django.db.models.fields.PositiveIntegerField')()),
            ('started_at', self.gf('django.db.models.fields.DateTimeField')()),
        ))
        db.send_create_signal(u'allejo', ['Championship'])

        # Adding M2M table for field players on 'Championship'
        m2m_table_name = db.shorten_name(u'allejo_championship_players')
        db.create_table(m2m_table_name, (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('championship', models.ForeignKey(orm[u'allejo.championship'], null=False)),
            ('player', models.ForeignKey(orm[u'allejo.player'], null=False))
        ))
        db.create_unique(m2m_table_name, ['championship_id', 'player_id'])

        # Adding model 'Player'
        db.create_table(u'allejo_player', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=200, db_index=True)),
            ('main_image', self.gf('django.db.models.fields.files.ImageField')(max_length=100, null=True, blank=True)),
        ))
        db.send_create_signal(u'allejo', ['Player'])

        # Adding model 'Match'
        db.create_table(u'allejo_match', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('home', self.gf('django.db.models.fields.related.ForeignKey')(related_name=u'home_player_set', to=orm['allejo.Player'])),
            ('home_score', self.gf('django.db.models.fields.IntegerField')(null=True, blank=True)),
            ('away', self.gf('django.db.models.fields.related.ForeignKey')(related_name=u'away_player_set', to=orm['allejo.Player'])),
            ('away_score', self.gf('django.db.models.fields.IntegerField')(null=True, blank=True)),
            ('championship', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['allejo.Championship'])),
            ('winner', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['allejo.Player'], null=True, blank=True)),
            ('game_date', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('location', self.gf('django.db.models.fields.CharField')(max_length=200)),
            ('category', self.gf('django.db.models.fields.CharField')(db_index=True, max_length=100, null=True, blank=True)),
            ('group', self.gf('django.db.models.fields.CharField')(db_index=True, max_length=1, null=True, blank=True)),
            ('turn', self.gf('django.db.models.fields.CharField')(db_index=True, max_length=1, null=True, blank=True)),
            ('main_image', self.gf('django.db.models.fields.files.ImageField')(max_length=100, null=True, blank=True)),
        ))
        db.send_create_signal(u'allejo', ['Match'])

        # Adding model 'Standings'
        db.create_table(u'allejo_standings', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('championship', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['allejo.Championship'])),
            ('player', self.gf('django.db.models.fields.related.ForeignKey')(related_name=u'player_set', to=orm['allejo.Player'])),
            ('category', self.gf('django.db.models.fields.CharField')(db_index=True, max_length=100, null=True, blank=True)),
            ('group', self.gf('django.db.models.fields.CharField')(db_index=True, max_length=1, null=True, blank=True)),
            ('turn', self.gf('django.db.models.fields.CharField')(db_index=True, max_length=1, null=True, blank=True)),
            ('games_played', self.gf('django.db.models.fields.IntegerField')(default=0)),
            ('points', self.gf('django.db.models.fields.IntegerField')(default=0)),
            ('wins', self.gf('django.db.models.fields.IntegerField')(default=0)),
            ('draws', self.gf('django.db.models.fields.IntegerField')(default=0)),
            ('losses', self.gf('django.db.models.fields.IntegerField')(default=0)),
            ('goals_for', self.gf('django.db.models.fields.IntegerField')(default=0)),
            ('goals_against', self.gf('django.db.models.fields.IntegerField')(default=0)),
            ('goals_difference', self.gf('django.db.models.fields.IntegerField')(default=0)),
        ))
        db.send_create_signal(u'allejo', ['Standings'])


    def backwards(self, orm):
        # Deleting model 'Championship'
        db.delete_table(u'allejo_championship')

        # Removing M2M table for field players on 'Championship'
        db.delete_table(db.shorten_name(u'allejo_championship_players'))

        # Deleting model 'Player'
        db.delete_table(u'allejo_player')

        # Deleting model 'Match'
        db.delete_table(u'allejo_match')

        # Deleting model 'Standings'
        db.delete_table(u'allejo_standings')


    models = {
        u'allejo.championship': {
            'Meta': {'object_name': 'Championship'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'main_image': ('django.db.models.fields.files.ImageField', [], {'max_length': '100', 'null': 'True', 'blank': 'True'}),
            'max_players': ('django.db.models.fields.PositiveIntegerField', [], {}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'players': ('django.db.models.fields.related.ManyToManyField', [], {'to': u"orm['allejo.Player']", 'symmetrical': 'False'}),
            'started_at': ('django.db.models.fields.DateTimeField', [], {})
        },
        u'allejo.match': {
            'Meta': {'object_name': 'Match'},
            'away': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "u'away_player_set'", 'to': u"orm['allejo.Player']"}),
            'away_score': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            'category': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '100', 'null': 'True', 'blank': 'True'}),
            'championship': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['allejo.Championship']"}),
            'game_date': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'group': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '1', 'null': 'True', 'blank': 'True'}),
            'home': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "u'home_player_set'", 'to': u"orm['allejo.Player']"}),
            'home_score': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'location': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'main_image': ('django.db.models.fields.files.ImageField', [], {'max_length': '100', 'null': 'True', 'blank': 'True'}),
            'turn': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '1', 'null': 'True', 'blank': 'True'}),
            'winner': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['allejo.Player']", 'null': 'True', 'blank': 'True'})
        },
        u'allejo.player': {
            'Meta': {'object_name': 'Player'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'main_image': ('django.db.models.fields.files.ImageField', [], {'max_length': '100', 'null': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '200', 'db_index': 'True'})
        },
        u'allejo.standings': {
            'Meta': {'object_name': 'Standings'},
            'category': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '100', 'null': 'True', 'blank': 'True'}),
            'championship': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['allejo.Championship']"}),
            'draws': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'games_played': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'goals_against': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'goals_difference': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'goals_for': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'group': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '1', 'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'losses': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'player': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "u'player_set'", 'to': u"orm['allejo.Player']"}),
            'points': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'turn': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '1', 'null': 'True', 'blank': 'True'}),
            'wins': ('django.db.models.fields.IntegerField', [], {'default': '0'})
        }
    }

    complete_apps = ['allejo']


# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Championship',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(max_length=200, verbose_name='Name')),
                ('main_image', models.ImageField(null=True, upload_to='allejo/championship', blank=True)),
                ('max_players', models.PositiveIntegerField(verbose_name='Max of players')),
                ('started_at', models.DateTimeField()),
            ],
            options={
                'verbose_name': 'Championship',
                'verbose_name_plural': 'Championships',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Match',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('home_score', models.IntegerField(null=True, verbose_name='Score home player', blank=True)),
                ('away_score', models.IntegerField(null=True, verbose_name='Score away player', blank=True)),
                ('game_date', models.DateTimeField(null=True, blank=True)),
                ('location', models.CharField(max_length=200, verbose_name='Location')),
                ('category', models.CharField(max_length=100, blank=True, help_text='Example: playoffs, final, quarter-final', null=True, verbose_name='Category', db_index=True)),
                ('group', models.CharField(max_length=1, blank=True, help_text='Example: A, B, C, D', null=True, verbose_name='Group', db_index=True)),
                ('turn', models.CharField(max_length=1, blank=True, help_text='Example: 1, 2', null=True, verbose_name='Turn', db_index=True)),
                ('main_image', models.ImageField(null=True, upload_to='allejo/match', blank=True)),
            ],
            options={
                'verbose_name': 'Match',
                'verbose_name_plural': 'Matches',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Player',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(max_length=200, verbose_name='Name', db_index=True)),
                ('main_image', models.ImageField(null=True, upload_to='allejo/player', blank=True)),
            ],
            options={
                'verbose_name': 'Player',
                'verbose_name_plural': 'Players',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Standings',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('category', models.CharField(max_length=100, blank=True, help_text='Example: playoffs, final, quarter-final', null=True, verbose_name='Category', db_index=True)),
                ('group', models.CharField(max_length=1, blank=True, help_text='Example: A, B, C, D', null=True, verbose_name='Group', db_index=True)),
                ('turn', models.CharField(max_length=1, blank=True, help_text='Example: 1, 2', null=True, verbose_name='Turn', db_index=True)),
                ('games_played', models.IntegerField(default=0, verbose_name='Games Played')),
                ('points', models.IntegerField(default=0, verbose_name='Points')),
                ('wins', models.IntegerField(default=0, verbose_name='Wins')),
                ('draws', models.IntegerField(default=0, verbose_name='Draws')),
                ('losses', models.IntegerField(default=0, verbose_name='Losses')),
                ('goals_for', models.IntegerField(default=0, verbose_name='Goals For')),
                ('goals_against', models.IntegerField(default=0, verbose_name='Goals Against')),
                ('goals_difference', models.IntegerField(default=0, verbose_name='Goals Difference')),
                ('championship', models.ForeignKey(verbose_name='Championship', to='allejo.Championship')),
                ('player', models.ForeignKey(related_name='player_set', verbose_name='Player', to='allejo.Player')),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='match',
            name='away',
            field=models.ForeignKey(related_name='away_player_set', verbose_name='Away player', to='allejo.Player'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='match',
            name='championship',
            field=models.ForeignKey(verbose_name='Choice a championship', to='allejo.Championship'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='match',
            name='home',
            field=models.ForeignKey(related_name='home_player_set', verbose_name='Home player', to='allejo.Player'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='match',
            name='winner',
            field=models.ForeignKey(verbose_name='Player winner', blank=True, to='allejo.Player', null=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='championship',
            name='players',
            field=models.ManyToManyField(to='allejo.Player', verbose_name='Players'),
            preserve_default=True,
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models
from django.utils.translation import ugettext_lazy as _


class Championship(models.Model):
    name = models.CharField(verbose_name=_('Name'), max_length=200)

    main_image = models.ImageField(
        upload_to='allejo/championship', blank=True, null=True)

    max_players = models.PositiveIntegerField(
        verbose_name=_('Max of players'))

    players = models.ManyToManyField(
        'Player', verbose_name=_('Players')
    )

    started_at = models.DateTimeField()

    class Meta:
        verbose_name = _('Championship')
        verbose_name_plural = _('Championships')

    def __unicode__(self):
        return self.name


class Player(models.Model):
    name = models.CharField(
        verbose_name=_('Name'), max_length=200, db_index=True)

    main_image = models.ImageField(
        upload_to='allejo/player', blank=True, null=True)

    class Meta:
        verbose_name = _('Player')
        verbose_name_plural = _('Players')

    def __unicode__(self):
        return self.name


class Match(models.Model):
    home = models.ForeignKey(
        'Player',
        verbose_name=_('Home player'),
        related_name='home_player_set'
    )

    home_score = models.IntegerField(
        verbose_name=_('Score home player'), blank=True, null=True
    )

    away = models.ForeignKey(
        'Player',
        verbose_name=_('Away player'),
        related_name='away_player_set')

    away_score = models.IntegerField(
        verbose_name=_('Score away player'), blank=True, null=True)

    championship = models.ForeignKey(
        'Championship',
        verbose_name=_('Choice a championship')
    )

    winner = models.ForeignKey(
        'Player',
        verbose_name=_('Player winner'),
        blank=True, null=True
    )

    game_date = models.DateTimeField(blank=True, null=True)

    location = models.CharField(
        verbose_name=_('Location'), max_length=200)

    category = models.CharField(
        verbose_name=_('Category'), max_length=100,
        blank=True, null=True, db_index=True,
        help_text=_('Example: playoffs, final, quarter-final')
    )

    group = models.CharField(
        verbose_name=_('Group'), max_length=1,
        blank=True, null=True, db_index=True,
        help_text=_('Example: A, B, C, D')
    )

    turn = models.CharField(
        verbose_name=_('Turn'), max_length=1,
        blank=True, null=True, db_index=True,
        help_text=_('Example: 1, 2')
    )

    main_image = models.ImageField(
        upload_to='allejo/match', blank=True, null=True)

    class Meta:
        verbose_name = _('Match')
        verbose_name_plural = _('Matches')

    def __unicode__(self):
        return "%s %s - %s" % (self.championship.name, self.home, self.away)


class Standings(models.Model):
    championship = models.ForeignKey(
        'Championship',
        verbose_name=_('Championship')
    )

    player = models.ForeignKey(
        'Player',
        verbose_name=_('Player'),
        related_name='player_set'
    )

    category = models.CharField(
        verbose_name=_('Category'), max_length=100,
        blank=True, null=True, db_index=True,
        help_text=_('Example: playoffs, final, quarter-final')
    )

    group = models.CharField(
        verbose_name=_('Group'), max_length=1,
        blank=True, null=True, db_index=True,
        help_text=_('Example: A, B, C, D')
    )

    turn = models.CharField(
        verbose_name=_('Turn'), max_length=1,
        blank=True, null=True, db_index=True,
        help_text=_('Example: 1, 2')
    )

    # standings table info
    games_played = models.IntegerField(
        verbose_name=_("Games Played"), default=0)

    points = models.IntegerField(
        verbose_name=_("Points"), default=0)

    wins = models.IntegerField(
        verbose_name=_("Wins"), default=0)

    draws = models.IntegerField(
        verbose_name=_("Draws"), default=0)

    losses = models.IntegerField(
        verbose_name=_("Losses"), default=0)

    goals_for = models.IntegerField(
        verbose_name=_("Goals For"), default=0)

    goals_against = models.IntegerField(
        verbose_name=_("Goals Against"), default=0)

    goals_difference = models.IntegerField(
        verbose_name=_("Goals Difference"), default=0)



from django.contrib import admin
from models import Championship, Player, Match


class ChampionshipAdmin(admin.ModelAdmin):
    filter_horizontal = ('players', )


admin.site.register(Championship, ChampionshipAdmin)
admin.site.register(Match)
admin.site.register(Player)



#!/usr/bin/env python
from setuptools import setup, find_packages
import os
import re
import sys


version = '0.1.0'
name = 'django-allejo'
package = 'allejo'
description = 'Management and creation for custom tournaments and \
rankings for many sports.'
url = 'http://github.com/lerrua/django-allejo'
author = 'Igor P. Leroy'
author_email = 'ip.leroy@gmail.com'
license = 'BSD'
install_requires = []

setup(
    name=name,
    version=version,
    url=url,
    author=author,
    author_email=author_email,
    license=license,
    packages=find_packages(),
    include_package_data=True,
    description=description,
    keywords = ['standings', 'soccer', 'football', 'ranking'],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python",
        "Operating System :: OS Independent",
        "Topic :: Software Development :: Libraries",
        "Topic :: Utilities",
        "Environment :: Web Environment",
        "Framework :: Django",
    ],
    install_requires=install_requires
)
